@@ -11,7 +11,7 @@ class Agent(object):
         self.__hmac_key = hmac_key
 
     def __encrypt(self, v: Any) -> str:
-        v = b64encode(EasyRSA(public_key=self.__key_pair["public_key"]).encrypt(json.dumps(v))).decode("utf-8")
+        v = b64e(EasyRSA(public_key=self.__key_pair["public_key"]).encrypt(json.dumps(v)))
         hash = mac(v, self.__hmac_key)
         return f"{hash} {v}"
 
@@ -22,7 +22,7 @@ class Agent(object):
     def __decrypt(self, v: str) -> Any:
         hash, v = v.split(" ")
         if hash == mac(v, self.__hmac_key):
-            return json.loads(EasyRSA(private_key=self.__key_pair["private_key"]).decrypt(b64decode(v)))
+            return json.loads(EasyRSA(private_key=self.__key_pair["private_key"]).decrypt(b64d(v)))
         raise Exception("credentials are tampered due to different hmac")
 
     def get(self, id: str, pw: str, k: str) -> Any:
